@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -153,4 +153,9 @@ public class SimPublicationService implements PublicationService {
         return deletedIds;
     }
 
+	public Collection<Publication> getAllPublications(Context ctx, int userId, String module) throws PublicationException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
 }
