@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,9 @@ public class Publication {
     private Map<String, Object> configuration = new HashMap<String, Object>();
 
     private String displayName;
-
+    
+    private Boolean enabled = null;
+    
     
     public int getId() {
         return id;
@@ -92,7 +94,11 @@ public class Publication {
     public void setEntityId(String entityId) {
         this.entityId = entityId;
     }
-
+    
+    public boolean containsEntityId() {
+        return getEntityId() != null;
+    }
+    
     public String getModule() {
         return module;
     }
@@ -100,6 +106,10 @@ public class Publication {
     public void setModule(String module) {
         this.module = module;
     }
+    
+    public boolean containsModule() {
+        return getModule() != null;
+    }
 
     public PublicationTarget getTarget() {
         return target;
@@ -109,6 +119,10 @@ public class Publication {
         this.target = target;
     }
 
+    public boolean containsTarget() {
+        return getTarget() != null;
+    }
+    
     public Map<String, Object> getConfiguration() {
         return configuration;
     }
@@ -124,6 +138,10 @@ public class Publication {
     public void setUserId(int userId) {
         this.userId = userId;
     }
+    
+    public boolean containsUserId() {
+        return this.getUserId() > 0;
+    }
 
     public Context getContext() {
         return context;
@@ -140,6 +158,18 @@ public class Publication {
     public void setDisplayName(String displayName) {
         this.displayName = displayName;
     }
+    
+    public boolean isEnabled() {
+        return enabled != null ? enabled : true;
+    }
+    
+    public void setEnabled(boolean enabled) {
+        this.enabled = enabled;
+    }
+    
+    public boolean containsEnabled() {
+        return enabled != null;
+    }
 
     public void create() throws PublicationException {
         getTarget().getPublicationService().create(this);
@@ -153,4 +183,8 @@ public class Publication {
         getTarget().getPublicationService().delete(this);
     }
 
+
+
+
+
 }
