@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,8 +66,12 @@ public interface PublicationStorage {
     public List<Publication> getPublications(Context ctx, String module, String entityId) throws PublicationException;
 
     public List<Publication> getPublications(Context ctx, String publicationTarget) throws PublicationException;
+    
+    public List<Publication> getPublicationsOfUser(Context ctx, int userId)  throws PublicationException;
+    
+    public List<Publication> getPublicationsOfUser(Context ctx, int userId, String module)  throws PublicationException;
 
-    public Publication getPublication(Context ctx, int publicationId) throws PublicationException;
+    public Publication getPublication(Context ctx, int publicationId) throws PublicationException;    
     
     public Collection<Publication> search(Context ctx, String targetId, Map<String, Object> query) throws PublicationException;
     
@@ -77,4 +81,5 @@ public interface PublicationStorage {
     
     public void deletePublicationsInContext(int contextId, Context ctx) throws PublicationException;
     
+    public Map<Entity, Boolean> isPublished(List<Entity> entities, Context ctx) throws PublicationException;
 }
